pub enum PropValue {
Show 139 variants
_0,
_1,
_10,
_11,
_12,
_13,
_14,
_15,
_16,
_17,
_18,
_19,
_2,
_20,
_21,
_22,
_23,
_24,
_25,
_3,
_4,
_5,
_6,
_7,
_8,
_9,
Accept,
Active,
AscendingEast,
AscendingNorth,
AscendingSouth,
AscendingWest,
Awake,
Banjo,
Base,
Basedrum,
Bass,
Bell,
Bit,
Bottom,
Ceiling,
Chime,
Compare,
Cooldown,
Corner,
CowBell,
Creeper,
CustomHead,
Data,
Didgeridoo,
Dormant,
Double,
DoubleWall,
Down,
DownEast,
DownNorth,
DownSouth,
DownWest,
Dragon,
East,
EastUp,
EastWest,
Ejecting,
EjectingReward,
Fail,
False,
Floor,
Flute,
Foot,
Frustum,
Full,
Guitar,
Harp,
Hat,
Head,
Inactive,
InnerLeft,
InnerRight,
IronXylophone,
Large,
Left,
Load,
Log,
Low,
Lower,
Middle,
None,
Normal,
North,
NorthEast,
NorthSouth,
NorthUp,
NorthWest,
OuterLeft,
OuterRight,
Partial,
Piglin,
Pling,
Right,
Save,
Side,
Single,
SingleWall,
Skeleton,
Small,
Snare,
South,
SouthEast,
SouthUp,
SouthWest,
Start,
Sticky,
Straight,
Subtract,
Tall,
Tip,
TipMerge,
Top,
True,
Unlocking,
Unstable,
Up,
UpEast,
UpNorth,
UpSouth,
UpWest,
Upper,
Uprooted,
WaitingForPlayers,
WaitingForRewardEjection,
Wall,
West,
WestUp,
WitherSkeleton,
X,
Xylophone,
Y,
Z,
Zombie,
}Expand description
Contains all possible values that a block property might have.
For example, upper, true, and 2 are all property values.
Variants
_0
_1
_10
_11
_12
_13
_14
_15
_16
_17
_18
_19
_2
_20
_21
_22
_23
_24
_25
_3
_4
_5
_6
_7
_8
_9
Accept
Active
AscendingEast
AscendingNorth
AscendingSouth
AscendingWest
Awake
Banjo
Base
Basedrum
Bass
Bell
Bit
Bottom
Ceiling
Chime
Compare
Cooldown
Corner
CowBell
Creeper
CustomHead
Data
Didgeridoo
Dormant
Double
DoubleWall
Down
DownEast
DownNorth
DownSouth
DownWest
Dragon
East
EastUp
EastWest
Ejecting
EjectingReward
Fail
False
Floor
Flute
Foot
Frustum
Full
Guitar
Harp
Hat
Head
Inactive
InnerLeft
InnerRight
IronXylophone
Large
Left
Load
Log
Low
Lower
Middle
None
Normal
North
NorthEast
NorthSouth
NorthUp
NorthWest
OuterLeft
OuterRight
Partial
Piglin
Pling
Right
Save
Side
Single
SingleWall
Skeleton
Small
Snare
South
SouthEast
SouthUp
SouthWest
Start
Sticky
Straight
Subtract
Tall
Tip
TipMerge
Top
True
Unlocking
Unstable
Up
UpEast
UpNorth
UpSouth
UpWest
Upper
Uprooted
WaitingForPlayers
WaitingForRewardEjection
Wall
West
WestUp
WitherSkeleton
X
Xylophone
Y
Z
Zombie
Implementations
Sourceimpl PropValue
impl PropValue
Sourcepub fn from_str(name: &str) -> Option<PropValue>
pub fn from_str(name: &str) -> Option<PropValue>
Construct a property value from its snake_case name.
Returns None if the given name is not valid.
Sourcepub const fn from_u16(n: u16) -> Option<PropValue>
pub const fn from_u16(n: u16) -> Option<PropValue>
Converts a u16 into a numeric property value.
Returns None if the given number does not have a
corresponding property value.
Sourcepub const fn to_u16(self) -> Option<u16>
pub const fn to_u16(self) -> Option<u16>
Converts this property value into a u16 if it is numeric.
Returns None otherwise.